<?php
/*
Plugin Name: Total - Responsive Toggle
Description: Adds a tiny bit of custom Javascript to the site's footer so that you can create any link that toggles the responsiveness of the theme on and off. Simply apply the classname "js-responsive-toggle" to any link and when that link is clicked it will remove or re-enable responsiveness.
Version: 1.0.0
Author: Aj Clarke
Author URI: http://www.wpexplorer.com
License: GPLv2
*/

// Start Class
class Total_Responsive_Toggle {

	/**
	 * Main constructor
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'wp_footer', array( 'Total_Responsive_Toggle', 'add_js' ) );
	}

	/**
	 * Adds the javascript for the toggle
	 *
	 * @since 1.0.0
	 */
	public static function add_js() {
		$vp_width = intval( wpex_get_mod( 'main_container_width' ) );
		$vp_width = $vp_width ? $vp_width: '980'; ?>

		<script>
			( function( $ ) {
				'use strict';
					var $totalSheet     = $( '#wpex-responsive-css' ),
						$totalSheetHref = $totalSheet.attr( 'href' ),
						$body           = $( 'body' ),
						$vcResponsive   = $body.hasClass( 'vc_responsive' ) ? true : false;
					$( '.js-responsive-toggle' ).click( function() {
						if ( $totalSheet.attr( 'href' ) ) {
							$body.removeClass( 'wpex-responsive' );
							$totalSheet.attr( 'href', '' );
							if ( $vcResponsive ) {
								$body.removeClass( 'vc_responsive' );
							}
							$( 'meta[name=viewport]' ).remove();
							$( 'head' ).append( '<meta name="viewport" content="width=<?php echo $vp_width; ?>" />' );
						} else {
							$body.addClass( 'wpex-responsive' );
							$totalSheet.attr( 'href', $totalSheetHref );
							if ( $vcResponsive ) {
								$body.addClass( 'vc_responsive' );
							}
							$( 'meta[name=viewport]' ).remove();
							$( 'head' ).append( '<meta name="viewport" content="width=device-width, initial-scale=1">' );
						}
						return false;
					} );

			} ) ( jQuery );
		</script>

	<?php }

}
new Total_Responsive_Toggle;